@@ -7,23 +7,28 @@
 /* global defaults */
 
 int (*action)(int *argc, char *argv[]) = &succeed;
-int batchmode = 0;
-size_t bpslimit = 0;
 char *bwlimit;
-int dryrun = 0;
-int g_archive = 0;
-int g_perms = 0;
-int hex = 0;
 char *iface = NULL;
-unsigned int ifx = 0;
 char *keyfile = NULL;
-int loopback = 0;
 char *password;
 char *progname;
-unsigned char secretkey[crypto_pwhash_STRBYTES];
+int archive = 0;
+int batchmode = 0;
+int dryrun = 0;
+int hex = 0;
+int loopback = 0;
 int quiet = 0;
+int recurse = 0;
+int remote = 0;
+int setgroup = 0;
+int setowner = 0;
+int setperms = 0;
+int settimes = 0;
 int verbose = 0;
 int version = 0;
+size_t bpslimit = 0;
+unsigned char secretkey[crypto_pwhash_STRBYTES];
+unsigned int ifx = 0;
 
 int succeed(int *argc, char *argv[])
 {
